@@ -123,10 +123,9 @@ def _replay(args, file_name, content):
         out = _create_file_name(file_name, args)
     playback = out_fmt.TextFormat()
     playback.replay(content, out)
-    exit(0)
 
 
-def main():
+def main(in_args=None):
     """Main-entry point."""
     utils.supported()
     default_font = fnt.Font().detect
@@ -193,7 +192,7 @@ token color to another color (override)""", metavar='N', type=str, nargs='+')
                         help="vertical start zoom")
     parser.add_argument('--vezoom', type=int, default=0,
                         help="vertical end zoom")
-    args = parser.parse_args()
+    args = parser.parse_args(args=in_args)
     if args.version:
         if not args.quiet:
             log.Log.writeln()
@@ -201,7 +200,7 @@ token color to another color (override)""", metavar='N', type=str, nargs='+')
         log.Log.write(vers.__version__)
         if not args.quiet:
             log.Log.writeln()
-        exit(0)
+        return
     if args.quiet:
         log.Log.is_verbose = False
     inputs = InputArgs(args)
@@ -260,6 +259,7 @@ def _run(args, default_font):
         content = "".join(sys.stdin.readlines())
     if is_raw:
         _replay(args, file_name, content)
+        return
     if is_auto:
         log.Log.write(content)
         try:
